==> percona-xtrabackup_8.4.0-1.orig.tar.gz: percona-xtrabackup-8.4.0-1/plugin/group_replication/include/udf/udf_multi_primary.h <==
/* Copyright (c) 2018, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef PLUGIN_GR_INCLUDE_UDF_MULTI_PRIMARY_H
#define PLUGIN_GR_INCLUDE_UDF_MULTI_PRIMARY_H

#include "plugin/group_replication/include/udf/udf_descriptor.h"

/**
 * Returns the descriptor of the "group_replication_switch_to_multi_primary"
 * UDF.
 *
 * @returns the descriptor of the "group_replication_switch_to_multi_primary"
 * UDF
 */
udf_descriptor switch_to_multi_primary_udf();

#endif /* PLUGIN_GR_INCLUDE_UDF_MULTI_PRIMARY_H */

==> percona-xtrabackup-80_8.0.26-18.orig.tar.gz: percona-xtrabackup-8.0.26-18/plugin/group_replication/include/udf/udf_multi_primary.h <==
/* Copyright (c) 2018, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef PLUGIN_GR_INCLUDE_UDF_MULTI_PRIMARY_H
#define PLUGIN_GR_INCLUDE_UDF_MULTI_PRIMARY_H

#include "plugin/group_replication/include/udf/udf_descriptor.h"

/**
 * Returns the descriptor of the "group_replication_switch_to_multi_primary"
 * UDF.
 *
 * @returns the descriptor of the "group_replication_switch_to_multi_primary"
 * UDF
 */
udf_descriptor switch_to_multi_primary_udf();

#endif /* PLUGIN_GR_INCLUDE_UDF_MULTI_PRIMARY_H */
